# coding: utf-8

# flake8: noqa
"""
    Rapidata.Dataset

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from rapidata.api_client.models.add_validation_rapid_model import AddValidationRapidModel
from rapidata.api_client.models.add_validation_rapid_model_payload import AddValidationRapidModelPayload
from rapidata.api_client.models.add_validation_rapid_model_truth import AddValidationRapidModelTruth
from rapidata.api_client.models.add_validation_rapid_result import AddValidationRapidResult
from rapidata.api_client.models.admin_order_model import AdminOrderModel
from rapidata.api_client.models.admin_order_model_paged_result import AdminOrderModelPagedResult
from rapidata.api_client.models.age_group import AgeGroup
from rapidata.api_client.models.age_user_filter_model import AgeUserFilterModel
from rapidata.api_client.models.aggregator_type import AggregatorType
from rapidata.api_client.models.attach_category_rapid_blueprint import AttachCategoryRapidBlueprint
from rapidata.api_client.models.attach_category_result import AttachCategoryResult
from rapidata.api_client.models.attach_category_truth import AttachCategoryTruth
from rapidata.api_client.models.base_error import BaseError
from rapidata.api_client.models.bounding_box_payload import BoundingBoxPayload
from rapidata.api_client.models.bounding_box_rapid_blueprint import BoundingBoxRapidBlueprint
from rapidata.api_client.models.bounding_box_result import BoundingBoxResult
from rapidata.api_client.models.bounding_box_truth import BoundingBoxTruth
from rapidata.api_client.models.box_shape import BoxShape
from rapidata.api_client.models.classification_metadata import ClassificationMetadata
from rapidata.api_client.models.classification_metadata_filter_config import ClassificationMetadataFilterConfig
from rapidata.api_client.models.classify_payload import ClassifyPayload
from rapidata.api_client.models.clone_dataset_model import CloneDatasetModel
from rapidata.api_client.models.clone_order_model import CloneOrderModel
from rapidata.api_client.models.clone_order_result import CloneOrderResult
from rapidata.api_client.models.compare_payload import ComparePayload
from rapidata.api_client.models.compare_rapid_blueprint import CompareRapidBlueprint
from rapidata.api_client.models.compare_result import CompareResult
from rapidata.api_client.models.compare_truth import CompareTruth
from rapidata.api_client.models.compare_workflow_config import CompareWorkflowConfig
from rapidata.api_client.models.compare_workflow_config_rapid_selection_configs_inner import CompareWorkflowConfigRapidSelectionConfigsInner
from rapidata.api_client.models.compare_workflow_config_referee import CompareWorkflowConfigReferee
from rapidata.api_client.models.compare_workflow_model import CompareWorkflowModel
from rapidata.api_client.models.conditional_validation_rapid_selection_config import ConditionalValidationRapidSelectionConfig
from rapidata.api_client.models.coordinate import Coordinate
from rapidata.api_client.models.correlated_rapid_selection_config import CorrelatedRapidSelectionConfig
from rapidata.api_client.models.count_classification_metadata_filter_config import CountClassificationMetadataFilterConfig
from rapidata.api_client.models.count_metadata import CountMetadata
from rapidata.api_client.models.country_user_filter_model import CountryUserFilterModel
from rapidata.api_client.models.create_client_model import CreateClientModel
from rapidata.api_client.models.create_complex_order_model import CreateComplexOrderModel
from rapidata.api_client.models.create_complex_order_model_pipeline import CreateComplexOrderModelPipeline
from rapidata.api_client.models.create_complex_order_result import CreateComplexOrderResult
from rapidata.api_client.models.create_dataset_artifact_model import CreateDatasetArtifactModel
from rapidata.api_client.models.create_dataset_artifact_model_dataset import CreateDatasetArtifactModelDataset
from rapidata.api_client.models.create_default_order_model import CreateDefaultOrderModel
from rapidata.api_client.models.create_default_order_model_workflow_config import CreateDefaultOrderModelWorkflowConfig
from rapidata.api_client.models.create_demographic_rapid_model import CreateDemographicRapidModel
from rapidata.api_client.models.create_empty_validation_set_result import CreateEmptyValidationSetResult
from rapidata.api_client.models.create_legacy_order_result import CreateLegacyOrderResult
from rapidata.api_client.models.create_order_model import CreateOrderModel
from rapidata.api_client.models.create_order_model_referee import CreateOrderModelReferee
from rapidata.api_client.models.create_order_model_selections_inner import CreateOrderModelSelectionsInner
from rapidata.api_client.models.create_order_model_user_filters_inner import CreateOrderModelUserFiltersInner
from rapidata.api_client.models.create_order_model_workflow import CreateOrderModelWorkflow
from rapidata.api_client.models.create_order_result import CreateOrderResult
from rapidata.api_client.models.create_simple_pipeline_model import CreateSimplePipelineModel
from rapidata.api_client.models.create_simple_pipeline_model_artifacts_inner import CreateSimplePipelineModelArtifactsInner
from rapidata.api_client.models.create_simple_pipeline_model_pipeline_steps_inner import CreateSimplePipelineModelPipelineStepsInner
from rapidata.api_client.models.create_unsupported_order_model import CreateUnsupportedOrderModel
from rapidata.api_client.models.customer_order_model import CustomerOrderModel
from rapidata.api_client.models.customer_order_model_paged_result import CustomerOrderModelPagedResult
from rapidata.api_client.models.datapoint import Datapoint
from rapidata.api_client.models.datapoint_asset import DatapointAsset
from rapidata.api_client.models.datapoint_get_by_id_get200_response import DatapointGetByIdGet200Response
from rapidata.api_client.models.datapoint_metadata_model import DatapointMetadataModel
from rapidata.api_client.models.datapoint_metadata_model_metadata_inner import DatapointMetadataModelMetadataInner
from rapidata.api_client.models.datapoint_model import DatapointModel
from rapidata.api_client.models.datapoint_model_asset import DatapointModelAsset
from rapidata.api_client.models.dataset_evaluation_step_model import DatasetEvaluationStepModel
from rapidata.api_client.models.demographic_rapid_selection_config import DemographicRapidSelectionConfig
from rapidata.api_client.models.demographic_selection import DemographicSelection
from rapidata.api_client.models.early_stopping_referee_model import EarlyStoppingRefereeModel
from rapidata.api_client.models.empty_validation_truth import EmptyValidationTruth
from rapidata.api_client.models.error_type import ErrorType
from rapidata.api_client.models.feature_flag import FeatureFlag
from rapidata.api_client.models.feature_flag_model import FeatureFlagModel
from rapidata.api_client.models.feedback_model import FeedbackModel
from rapidata.api_client.models.file_asset import FileAsset
from rapidata.api_client.models.file_asset_metadata_inner import FileAssetMetadataInner
from rapidata.api_client.models.file_asset_model import FileAssetModel
from rapidata.api_client.models.filter import Filter
from rapidata.api_client.models.filter_operator import FilterOperator
from rapidata.api_client.models.free_text_payload import FreeTextPayload
from rapidata.api_client.models.free_text_rapid_blueprint import FreeTextRapidBlueprint
from rapidata.api_client.models.free_text_result import FreeTextResult
from rapidata.api_client.models.gender import Gender
from rapidata.api_client.models.gender_user_filter_model import GenderUserFilterModel
from rapidata.api_client.models.get_available_validation_sets_result import GetAvailableValidationSetsResult
from rapidata.api_client.models.get_datapoints_by_dataset_id_result import GetDatapointsByDatasetIdResult
from rapidata.api_client.models.get_dataset_by_id_result import GetDatasetByIdResult
from rapidata.api_client.models.get_order_by_id_result import GetOrderByIdResult
from rapidata.api_client.models.get_order_results_result import GetOrderResultsResult
from rapidata.api_client.models.get_public_orders_result import GetPublicOrdersResult
from rapidata.api_client.models.get_workflow_config_result import GetWorkflowConfigResult
from rapidata.api_client.models.get_workflow_config_result_workflow_config import GetWorkflowConfigResultWorkflowConfig
from rapidata.api_client.models.image_dimension_metadata import ImageDimensionMetadata
from rapidata.api_client.models.import_from_file_result import ImportFromFileResult
from rapidata.api_client.models.import_validation_set_from_file_result import ImportValidationSetFromFileResult
from rapidata.api_client.models.issue_auth_token_result import IssueAuthTokenResult
from rapidata.api_client.models.issue_client_auth_token_result import IssueClientAuthTokenResult
from rapidata.api_client.models.labeling_selection import LabelingSelection
from rapidata.api_client.models.line import Line
from rapidata.api_client.models.line_payload import LinePayload
from rapidata.api_client.models.line_point import LinePoint
from rapidata.api_client.models.line_rapid_blueprint import LineRapidBlueprint
from rapidata.api_client.models.line_result import LineResult
from rapidata.api_client.models.line_truth import LineTruth
from rapidata.api_client.models.locate_box_truth import LocateBoxTruth
from rapidata.api_client.models.locate_coordinate import LocateCoordinate
from rapidata.api_client.models.locate_payload import LocatePayload
from rapidata.api_client.models.locate_rapid_blueprint import LocateRapidBlueprint
from rapidata.api_client.models.locate_result import LocateResult
from rapidata.api_client.models.location_metadata import LocationMetadata
from rapidata.api_client.models.location_metadata_exists_filter_config import LocationMetadataExistsFilterConfig
from rapidata.api_client.models.logic_operator import LogicOperator
from rapidata.api_client.models.login_model import LoginModel
from rapidata.api_client.models.metadata_visibilities import MetadataVisibilities
from rapidata.api_client.models.multi_asset import MultiAsset
from rapidata.api_client.models.multi_asset_model import MultiAssetModel
from rapidata.api_client.models.naive_referee_config import NaiveRefereeConfig
from rapidata.api_client.models.naive_referee_model import NaiveRefereeModel
from rapidata.api_client.models.named_classification import NamedClassification
from rapidata.api_client.models.named_entity_payload import NamedEntityPayload
from rapidata.api_client.models.named_entity_rapid_blueprint import NamedEntityRapidBlueprint
from rapidata.api_client.models.named_entity_result import NamedEntityResult
from rapidata.api_client.models.named_entity_truth import NamedEntityTruth
from rapidata.api_client.models.never_ending_referee_config import NeverEndingRefereeConfig
from rapidata.api_client.models.newsletter_model import NewsletterModel
from rapidata.api_client.models.no_validation_workflow_rapid_selection_config import NoValidationWorkflowRapidSelectionConfig
from rapidata.api_client.models.null_asset import NullAsset
from rapidata.api_client.models.null_asset_model import NullAssetModel
from rapidata.api_client.models.only_validation_workflow_rapid_selection_config import OnlyValidationWorkflowRapidSelectionConfig
from rapidata.api_client.models.order_model import OrderModel
from rapidata.api_client.models.order_query_get200_response import OrderQueryGet200Response
from rapidata.api_client.models.original_filename_metadata import OriginalFilenameMetadata
from rapidata.api_client.models.page_info import PageInfo
from rapidata.api_client.models.polygon_payload import PolygonPayload
from rapidata.api_client.models.polygon_rapid_blueprint import PolygonRapidBlueprint
from rapidata.api_client.models.polygon_result import PolygonResult
from rapidata.api_client.models.polygon_truth import PolygonTruth
from rapidata.api_client.models.private_text_metadata_input import PrivateTextMetadataInput
from rapidata.api_client.models.probabilistic_attach_category_referee_config import ProbabilisticAttachCategoryRefereeConfig
from rapidata.api_client.models.prompt_metadata import PromptMetadata
from rapidata.api_client.models.prompt_metadata_input import PromptMetadataInput
from rapidata.api_client.models.public_text_metadata_input import PublicTextMetadataInput
from rapidata.api_client.models.query_model import QueryModel
from rapidata.api_client.models.query_orders_model import QueryOrdersModel
from rapidata.api_client.models.query_validation_rapids_result import QueryValidationRapidsResult
from rapidata.api_client.models.query_validation_rapids_result_asset import QueryValidationRapidsResultAsset
from rapidata.api_client.models.query_validation_rapids_result_paged_result import QueryValidationRapidsResultPagedResult
from rapidata.api_client.models.query_validation_set_model import QueryValidationSetModel
from rapidata.api_client.models.rapid_result_model import RapidResultModel
from rapidata.api_client.models.rapid_result_model_result import RapidResultModelResult
from rapidata.api_client.models.rapid_skipped_model import RapidSkippedModel
from rapidata.api_client.models.request_password_reset_command import RequestPasswordResetCommand
from rapidata.api_client.models.root_filter import RootFilter
from rapidata.api_client.models.send_completion_mail_step_model import SendCompletionMailStepModel
from rapidata.api_client.models.shape import Shape
from rapidata.api_client.models.signup_customer_model import SignupCustomerModel
from rapidata.api_client.models.signup_shadow_customer_model import SignupShadowCustomerModel
from rapidata.api_client.models.simple_workflow_config import SimpleWorkflowConfig
from rapidata.api_client.models.simple_workflow_config_blueprint import SimpleWorkflowConfigBlueprint
from rapidata.api_client.models.simple_workflow_model import SimpleWorkflowModel
from rapidata.api_client.models.simple_workflow_model_blueprint import SimpleWorkflowModelBlueprint
from rapidata.api_client.models.skip_result import SkipResult
from rapidata.api_client.models.sort_criterion import SortCriterion
from rapidata.api_client.models.sort_direction import SortDirection
from rapidata.api_client.models.static_rapid_selection_config import StaticRapidSelectionConfig
from rapidata.api_client.models.submit_coco_model import SubmitCocoModel
from rapidata.api_client.models.submit_coco_result import SubmitCocoResult
from rapidata.api_client.models.submit_password_reset_command import SubmitPasswordResetCommand
from rapidata.api_client.models.text_asset import TextAsset
from rapidata.api_client.models.text_asset_model import TextAssetModel
from rapidata.api_client.models.text_metadata import TextMetadata
from rapidata.api_client.models.transcription_metadata import TranscriptionMetadata
from rapidata.api_client.models.transcription_metadata_input import TranscriptionMetadataInput
from rapidata.api_client.models.transcription_payload import TranscriptionPayload
from rapidata.api_client.models.transcription_rapid_blueprint import TranscriptionRapidBlueprint
from rapidata.api_client.models.transcription_result import TranscriptionResult
from rapidata.api_client.models.transcription_truth import TranscriptionTruth
from rapidata.api_client.models.transcription_word import TranscriptionWord
from rapidata.api_client.models.unlock_order_result import UnlockOrderResult
from rapidata.api_client.models.update_access_model import UpdateAccessModel
from rapidata.api_client.models.update_order_model import UpdateOrderModel
from rapidata.api_client.models.update_workflow_config_model import UpdateWorkflowConfigModel
from rapidata.api_client.models.update_workflow_config_model_workflow_config import UpdateWorkflowConfigModelWorkflowConfig
from rapidata.api_client.models.upload_coco_result import UploadCocoResult
from rapidata.api_client.models.upload_datapoints_result import UploadDatapointsResult
from rapidata.api_client.models.upload_files_from_s3_bucket_model import UploadFilesFromS3BucketModel
from rapidata.api_client.models.upload_text_sources_to_dataset_model import UploadTextSourcesToDatasetModel
from rapidata.api_client.models.validation_chance import ValidationChance
from rapidata.api_client.models.validation_import_post_request_blueprint import ValidationImportPostRequestBlueprint
from rapidata.api_client.models.validation_rapid_selection_config import ValidationRapidSelectionConfig
from rapidata.api_client.models.validation_selection import ValidationSelection
from rapidata.api_client.models.validation_set import ValidationSet
from rapidata.api_client.models.validation_set_overview_model import ValidationSetOverviewModel
from rapidata.api_client.models.validation_set_paged_result import ValidationSetPagedResult
from rapidata.api_client.models.workflow_aggregation_step_model import WorkflowAggregationStepModel
from rapidata.api_client.models.workflow_labeling_step_model import WorkflowLabelingStepModel
from rapidata.api_client.models.workflow_split_model import WorkflowSplitModel
from rapidata.api_client.models.workflow_split_model_filter_configs_inner import WorkflowSplitModelFilterConfigsInner
